# # urpmi mercurial
# $ hg clone https://bitbucket.org/tortoisehg/thg
# $ cd thg
# $ python3 setup.py sdist

# comment out if not hg snapshot
#global hgrel	89
#global hgrev	a808f7dad51e

# filter out auto deps as required typelib is defined from a file name
# nautilus-thg.py vs. caja-thg.py
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^typelib\\(Caja\\)
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^typelib\\(Nautilus\\)

%define rel	1

Name:           tortoisehg
Version:        7.0.1
Release:        %mkrel %{?hgrel:%hgrel.%hgrev.}%{rel}
Summary:        Mercurial GUI command line tool thg
Group:          Development/Tools
License:        GPLv2
# - few files are however under the more permissive GPLv2+
URL:            https://tortoisehg.bitbucket.io/
Source0:        https://www.mercurial-scm.org/release/tortoisehg/targz/%{name}-%{version}%{?hgrel:+%hgrel-%hgrev}.tar.gz
BuildArch:      noarch

BuildRequires:  gettext
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(mercurial)
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-qt6-devel
BuildRequires:  python3dist(sip)

Requires:       mercurial >= 6.9
Requires:       python3-qt6
Requires:       python3-qt6-qscintilla
Requires:       python3-iniparse
Requires:       python3-pygments

%description
This package contains the thg command line tool, which provides a graphical
user interface to the Mercurial distributed revision control system.

%package        nautilus
Summary:        Mercurial GUI plug-in to the Nautilus file manager
Group:          Development/Tools
Requires:       python3-gobject3
Requires:       %{name} = %{version}-%{release}
Requires:       nautilus-python
Requires:       typelib(Nautilus)

%description    nautilus
This package contains the TortoiseHg Gnome/Nautilus extension, which makes the
Mercurial distributed revision control system available in the file manager
with a graphical interface.

%package        caja
Summary:        Mercurial GUI plug-in to the Caja file manager
Group:          Development/Tools
Requires:       python3-gobject3
Requires:       %{name} = %{version}-%{release}
Requires:       caja-python
Requires:       typelib(Caja)

%description    caja
This package contains the TortoiseHg MATE/Caja extension, which makes the
Mercurial distributed revision control system available in the file manager
with a graphical interface.

%prep
%autosetup -p1 -n %{name}-%{version}%{?hgrel:+%hgrel-%hgrev}

cat > tortoisehg/util/config.py << EOT
bin_path     = "%{_bindir}"
license_path = "%{_docdir}/%{name}-%{version}/COPYING.txt"
locale_path  = "%{_datadir}/locale"
icon_path    = "%{_datadir}/pixmaps/tortoisehg/icons"
nofork       = True
EOT

%build
%pyproject_wheel

make -C doc html
rm doc/build/html/.buildinfo

%install
%pyproject_install

mkdir -p %{buildroot}%{_sysconfdir}/mercurial/hgrc.d
install contrib/mergetools.rc %{buildroot}%{_sysconfdir}/mercurial/hgrc.d/thgmergetools.rc

mkdir -p %{buildroot}%{_datadir}/pixmaps/tortoisehg/icons/svg
cp icons/svg/* %{buildroot}%{_datadir}/pixmaps/tortoisehg/icons/svg

desktop-file-install --dir=%{buildroot}%{_datadir}/applications contrib/thg.desktop

# caja extension
mkdir -p %{buildroot}%{_datadir}/caja-python/extensions/
install -Dpm644 contrib/nautilus-thg.py %{buildroot}%{_datadir}/caja-python/extensions/caja-thg.py

# bytecompile caja extension
%py_byte_compile %python3 %{buildroot}%{_datadir}/caja-python/extensions/

# Remove conflicting files
rm -f %{buildroot}%{python3_sitelib}/hgext3rd/__init*

# Handled in %%files section
rm -rf %{buildroot}%{_docdir}/%{name}/COPYING.txt

%find_lang %{name}

%files -f %{name}.lang
%license COPYING.txt
%doc doc/build/html/
%{_bindir}/thg
%{python3_sitelib}/hgext3rd/
%{python3_sitelib}/tortoisehg/
%{python3_sitelib}/tortoisehg-%{version}.dist-info/
%{_datadir}/pixmaps/tortoisehg/
%{_datadir}/pixmaps/thg_logo.svg
%{_datadir}/applications/thg.desktop

%config(noreplace) %attr(644,root,root) %{_sysconfdir}/mercurial/hgrc.d/thgmergetools.rc

%files nautilus
%pycached %{_datadir}/nautilus-python/extensions/nautilus-thg.py

%files caja
%pycached %{_datadir}/caja-python/extensions/caja-thg.py


%changelog
* Wed Apr 30 2025 wally <wally> 7.0.1-1.mga10
+ Revision: 2180126
- new version 7.0.1

* Fri Feb 28 2025 daviddavid <daviddavid> 6.9-1.mga10
+ Revision: 2153718
- new version: 6.9

* Fri Feb 28 2025 daviddavid <daviddavid> 6.6.3-3.mga10
+ Revision: 2153704
- rebuild for python 3.13

* Fri Aug 16 2024 daviddavid <daviddavid> 6.6.3-2.mga10
+ Revision: 2086717
- switch to PyQt6

* Wed Mar 06 2024 daviddavid <daviddavid> 6.6.3-1.mga10
+ Revision: 2047793
- new version: 6.6.3

* Sun Feb 25 2024 daviddavid <daviddavid> 6.5.1-2.mga10
+ Revision: 2044110
- rebuild for py3.12

* Mon Dec 04 2023 daviddavid <daviddavid> 6.5.1-1.mga10
+ Revision: 2012910
- new version: 6.5.1

* Sat Sep 10 2022 neoclust <neoclust> 6.2.2-1.mga9
+ Revision: 1886304
- New version 6.2.2

* Thu Jul 28 2022 wally <wally> 5.9.2-1.mga9
+ Revision: 1872695
- new version 5.9.2
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ tmb <tmb>
- rebuild for python 3.10

* Wed Mar 24 2021 daviddavid <daviddavid> 5.7.1-1.mga9
+ Revision: 1708934
- new version: 5.7.1
+ tv <tv>
- rebuild for python 3.9

* Wed Mar 10 2021 daviddavid <daviddavid> 5.7-1.mga9
+ Revision: 1700927
- new version: 5.7

* Tue Dec 15 2020 daviddavid <daviddavid> 5.6.1-1.mga8
+ Revision: 1657713
- new version: 5.6.1

* Sun Nov 08 2020 daviddavid <daviddavid> 5.6-1.mga8
+ Revision: 1643814
- new version: 5.6

* Thu Aug 13 2020 daviddavid <daviddavid> 5.5-1.mga8
+ Revision: 1613831
- new version: 5.5

* Wed Jun 24 2020 daviddavid <daviddavid> 5.4.1-1.mga8
+ Revision: 1599032
- new version: 5.4.1

* Tue Apr 28 2020 daviddavid <daviddavid> 5.3.2-1.mga8
+ Revision: 1572810
- new version: 5.3.2

* Wed Sep 25 2019 daviddavid <daviddavid> 5.1-89.a808f7dad51e.3.mga8
+ Revision: 1445794
- rebuild for python3.8

* Thu Aug 29 2019 wally <wally> 5.1-89.a808f7dad51e.2.mga8
+ Revision: 1435043
- add tortoisehg-caja
- fix requires

* Wed Aug 28 2019 wally <wally> 5.1-89.a808f7dad51e.1.mga8
+ Revision: 1434921
- update to latest hg snapshot 5.1+89-a808f7dad51e

* Sun Mar 10 2019 wally <wally> 4.7.2-4.mga7
+ Revision: 1373792
- add patch to use xdg-open for URLs
- drop unneeded gnome-python-gconf require

* Thu Nov 22 2018 kekepower <kekepower> 4.7.2-3.mga7
+ Revision: 1333366
- Also openssh-askpass-qt5
- Switch to python-qt5

* Thu Nov 22 2018 kekepower <kekepower> 4.7.2-2.mga7
+ Revision: 1333348
- Remove files that conflicts with Mercurial

* Thu Nov 22 2018 kekepower <kekepower> 4.7.2-1.mga7
+ Revision: 1333154
- BR python2dist(sip)
- Update to version 4.7.2 (mga#23856)

* Fri Sep 21 2018 umeabot <umeabot> 4.1.2-3.mga7
+ Revision: 1291924
- Mageia 7 Mass Rebuild

* Sat Jun 16 2018 anaselli <anaselli> 4.1.2-2.mga7
+ Revision: 1237292
- fix mga#23095 - Tortoisehg desktop icon missing in KDE menu

* Tue Apr 11 2017 shlomif <shlomif> 4.1.2-1.mga6
+ Revision: 1096404
- New version 4.1.2 + .spec updates.

* Sat Sep 10 2016 matteo <matteo> 3.9-1.mga6
+ Revision: 1051394
- new version 3.9

* Tue Feb 09 2016 umeabot <umeabot> 3.5.1-2.mga6
+ Revision: 951848
- Mageia 6 Mass Rebuild
+ anaselli <anaselli>
- fixed deps
- included new upstream version

* Sun Nov 23 2014 matteo <matteo> 3.2.1-1.mga5
+ Revision: 798540
- new release 3.2.1
- new minor release 3.1.1

* Wed Oct 15 2014 umeabot <umeabot> 3.1-4.mga5
+ Revision: 741907
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.1-3.mga5
+ Revision: 730625
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.1-2.mga5
+ Revision: 689928
- Mageia 5 Mass Rebuild
+ ovitters <ovitters>
- add gobject-introspection BR for typelib auto BR

* Sun Aug 10 2014 anaselli <anaselli> 3.1-1.mga5
+ Revision: 661385
- New version 3.1

* Sat May 31 2014 pterjan <pterjan> 2.11.1-3.mga5
+ Revision: 629190
- Rebuild for new Python

* Wed Apr 30 2014 anaselli <anaselli> 2.11.1-2.mga5
+ Revision: 619038
- Fixed Bug 13289 - Tortoise Hg Desktop shortcut missing icon

* Sun Mar 16 2014 matteo <matteo> 2.11.1-1.mga5
+ Revision: 604091
- new version 2.11.1

* Thu Mar 06 2014 matteo <matteo> 2.11-1.mga5
+ Revision: 600510
- new stable version (2.11)

* Thu Feb 06 2014 matteo <matteo> 2.9.2-1.mga5
+ Revision: 584844
- version 2.9.2 (minimum requirement to fix bug mga#12619 , thg not compatible with mercurial version)

* Sat Nov 02 2013 fwang <fwang> 2.8-4.mga4
+ Revision: 549032
- add requires

* Tue Oct 22 2013 umeabot <umeabot> 2.8-3.mga4
+ Revision: 544611
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.8-2.mga4
+ Revision: 499917
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Jun 21 2013 matteo <matteo> 2.8-1.mga4
+ Revision: 445553
- new version

* Sat Feb 09 2013 kamil <kamil> 2.7-1.mga3
+ Revision: 397257
- new version 2.7
- clean .spec a bit

* Mon Jan 14 2013 umeabot <umeabot> 2.6.2-2.mga3
+ Revision: 384691
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 matteo <matteo> 2.6.2-1.mga3
+ Revision: 340407
- new version

* Sun Dec 09 2012 matteo <matteo> 2.6-1.mga3
+ Revision: 329076
- new version

* Sat Nov 10 2012 matteo <matteo> 2.5.1-1.mga3
+ Revision: 316897
- new minor version

* Sun Oct 21 2012 malo <malo> 2.5-2.mga3
+ Revision: 308966
- update RPM group

* Fri Sep 28 2012 matteo <matteo> 2.5-1.mga3
+ Revision: 299141
- spec file reviewed
+ anaselli <anaselli>
- new version 2.5

* Mon Aug 06 2012 matteo <matteo> 2.4.2-1.mga3
+ Revision: 279205
- new version

* Wed Jun 13 2012 matteo <matteo> 2.4.1-1.mga3
+ Revision: 260318
- new version

* Sun Jun 03 2012 matteo <matteo> 2.4-1.mga3
+ Revision: 253824
- new version

* Tue May 01 2012 anaselli <anaselli> 2.3.2-1.mga2
+ Revision: 234447
- Added a check for missing ~/.tortoisehg
- Fixed nautilus menu (right position is /usr/share/nautilus-python/extensions)
  Fixed as noarch now
- new 2.3.2

* Mon Mar 05 2012 matteo <matteo> 2.3.1-1.mga2
+ Revision: 218299
- new version

* Thu Jan 05 2012 matteo <matteo> 2.2.2-2.mga2
+ Revision: 191952
+ rebuild (emptylog)

* Tue Jan 03 2012 matteo <matteo> 2.2.2-1.mga2
+ Revision: 189951
- version upgrade

* Fri Dec 09 2011 matteo <matteo> 2.2.1-1.mga2
+ Revision: 179571
- new version 2.2.1

* Fri Nov 11 2011 matteo <matteo> 2.2-1.mga2
+ Revision: 166387
- version upgrade

* Sat Nov 05 2011 anaselli <anaselli> 2.1.4-2.mga2
+ Revision: 163765
- hg version to fix mercurial 2.0 dependecy

* Sun Oct 09 2011 matteo <matteo> 2.1.4-1.mga2
+ Revision: 153595
- upgraded to version 2.1.4

* Sun Sep 04 2011 matteo <matteo> 2.1.3-1.mga2
+ Revision: 138477
- spec upgraded to the new software version
- imported package tortoisehg

